@@ -1,16 +1,17 @@
-# Copyrights 1995-2007 by Mark Overmeer <perl@overmeer.net>.
+# Copyrights 1995-2010 by Mark Overmeer <perl@overmeer.net>.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.03.
+# Pod stripped from pm file by OODoc 1.06.
 package Mail::Internet;
 use vars '$VERSION';
-$VERSION = '2.01';
+$VERSION = '2.07';
+
 use strict;
 # use warnings?  probably breaking too much code
 
 use Carp;
 use Mail::Header;
-use Mail::Util;
+use Mail::Util    qw/mailaddress/;
 use Mail::Address;
 
 
@@ -418,8 +419,6 @@ sub smtpsend($@)
 
     my $head = $self->cleaned_header_dup;
 
-    $head->delete('Bcc');
-
     # Who is it to
 
     my @rcpt = map { ref $_ ? @$_ : $_ } grep { defined } @opt{'To','Cc','Bcc'};
@@ -429,6 +428,8 @@ sub smtpsend($@)
     my @addr = map {$_->address} Mail::Address->parse(@rcpt);
     @addr or return ();
 
+    $head->delete('Bcc');
+
     # Send it
 
     my $ok = $smtp->mail($envelope)
